/* libopt++/src/libopt++/Parser.h
 *
 *  (c)2006, Laurence Withers. Released under the GNU GPL. See file
 *  COPYING for more information / terms of license.
*/

namespace opt {



/*! \brief Exception thrown when options cannot be parsed.

This exception is thrown whenever the options for a program cannot be parsed, meaning that either an
option is missing a required argument, or an option is not recognised at all. It is derived from
std::exception and has its what() method overloaded to print a useful description of the error.
Alternatively, you can get this from the msg member.

*/
class BadArg : public std::exception {
public:
    /*! \brief Constructor.

    \param msg Message explanining the error.

    */
    BadArg(const std::string& msg) : msg(msg) { }

    /// Destructor (does nothing special).
    virtual ~BadArg() throw() { }

    /// A message explaining the error.
    const std::string msg;

    /// Returns \a msg.
    virtual const char* what() const throw() { return msg.c_str(); }
};



}

/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
*/
